@@ -28,7 +28,9 @@ from .style import qctrl_style
 
 
 @qctrl_style()
-def plot_controls(figure, controls, polar=True, smooth=False):
+def plot_controls(
+    figure, controls, polar=True, smooth=False, unit_symbol="Hz", two_pi_factor=True
+):
     """
     Creates a plot of the specified controls.
 
@@ -40,8 +42,8 @@ def plot_controls(figure, controls, polar=True, smooth=False):
     controls : dict
         The dictionary of controls to plot. The keys should be the names of the controls, and the
         values the list of segments representing the pulse of that control. Each such segment must
-        be a dictionary with 'value' and 'duration' keys, giving the value (in Hertz, possibly
-        complex) and duration (in seconds) of that segment of the pulse.
+        be a dictionary with 'value' and 'duration' keys, giving the value (possibly complex, in the
+        units specified by `unit_symbol`) and duration (in seconds) of that segment of the pulse.
         For example, the following would be a valid ``controls`` input::
 
             {
@@ -63,6 +65,11 @@ def plot_controls(figure, controls, polar=True, smooth=False):
     smooth : bool, optional
         Whether to plot the controls as samples joined by straight lines, rather than as
         piecewise-constant segments. Defaults to False.
+    unit_symbol : str, optional
+        The symbol of the unit to which the controls values correspond. Defaults to "Hz".
+    two_pi_factor : bool, optional
+        Whether the values of the controls should be divided by 2π in the plots.
+        Defaults to True.
 
     Raises
     ------
@@ -78,7 +85,7 @@ def plot_controls(figure, controls, polar=True, smooth=False):
             values.append(segment["value"])
         values = np.array(values)
         plots_data = plots_data + _create_plots_data_from_control(
-            name, durations, values, polar
+            name, durations, values, polar, unit_symbol, two_pi_factor
         )
 
     # Get the appropriate scaling for the time axis based on the total durations of all controls.
@@ -149,7 +156,9 @@ def plot_controls(figure, controls, polar=True, smooth=False):
 
 
 @qctrl_style()
-def plot_smooth_controls(figure, controls, polar=True):
+def plot_smooth_controls(
+    figure, controls, polar=True, unit_symbol="Hz", two_pi_factor=True
+):
     """
     Creates a plot of the specified smooth controls.
 
@@ -161,8 +170,9 @@ def plot_smooth_controls(figure, controls, polar=True):
     controls : dict
         The dictionary of controls to plot. The keys should be the names of the controls, and the
         values the list of samples representing the pulse of that control. Each such sample must
-        be a dictionary with 'value' and 'time' keys, giving the value (in Hertz, possibly complex)
-        and time (in seconds) of that sample of the pulse. The times must be in increasing order.
+        be a dictionary with 'value' and 'time' keys, giving the value (possibly complex, in the
+        units specified by `unit_symbol`)  and time (in seconds) of that sample of the pulse. The
+        times must be in increasing order.
         For example, the following would be a valid ``controls`` input::
 
             {
@@ -180,6 +190,11 @@ def plot_smooth_controls(figure, controls, polar=True):
         The mode of the plot when the values appear to be complex numbers.
         Plot magnitude and angle in two figures if set to True, otherwise plot I and Q
         in two figures. Defaults to True.
+    unit_symbol : str, optional
+        The symbol of the unit to which the controls values correspond. Defaults to "Hz".
+    two_pi_factor : bool, optional
+        Whether the values of the controls should be divided by 2π in the plots.
+        Defaults to True.
 
     Raises
     ------
@@ -195,7 +210,7 @@ def plot_smooth_controls(figure, controls, polar=True):
             values.append(sample["value"])
         values = np.array(values)
         plots_data = plots_data + _create_plots_data_from_control(
-            name, times, values, polar
+            name, times, values, polar, unit_symbol, two_pi_factor
         )
 
     # Get the appropriate scaling for the time axis based on the total durations of all controls.
@@ -268,49 +283,61 @@ def _get_units(values):
     return 10 ** exponent_clipped, prefixes[exponent_clipped]
 
 
-def _create_plots_data_from_control(name, xdata, values, polar):
+def _create_plots_data_from_control(
+    name, xdata, values, polar, unit_symbol, two_pi_factor
+):
     """
     Creates a list of _PlotData objects for the given control data.
     """
+
+    # Scale values (and name) if they're to be divided by 2π
+    if two_pi_factor:
+        scaled_values = values / (2 * np.pi)
+        scaled_name = f"{name}$/2\\pi$"
+    else:
+        scaled_values = values
+        scaled_name = name
+
     if not np.iscomplexobj(values):
         # Real control.
-        value_scaling, value_prefix = _get_units(values / (2 * np.pi))
+        prefix_scaling, prefix = _get_units(scaled_values)
         return [
             _PlotData(
                 xdata=xdata,
-                values=values / (2 * np.pi) / value_scaling,
-                ylabel="{0}$/2\\pi$\n({1}Hz)".format(name, value_prefix),
+                values=scaled_values / prefix_scaling,
+                ylabel=f"{scaled_name}\n({prefix}{unit_symbol})",
             )
         ]
+
     if polar:
         # Complex control, split into polar coordinates.
-        value_scaling, value_prefix = _get_units(values / (2 * np.pi))
+        prefix_scaling, prefix = _get_units(scaled_values)
         return [
             _PlotData(
                 xdata=xdata,
-                values=np.abs(values / (2 * np.pi) / value_scaling),
-                ylabel="{0}$/2\\pi$\nModulus\n({1}Hz)".format(name, value_prefix),
+                values=np.abs(scaled_values) / prefix_scaling,
+                ylabel=f"{scaled_name}\nModulus\n({prefix}{unit_symbol})",
             ),
             _PlotData(
                 xdata=xdata,
                 values=np.angle(values),
-                ylabel="{0}\nAngle\n(rad)".format(name),
+                ylabel=f"{name}\nAngle\n(rad)",
             ),
         ]
 
     # Complex control, split into rectangle coordinates.
-    value_scaling_x, value_prefix_x = _get_units(np.real(values / (2 * np.pi)))
-    value_scaling_y, value_prefix_y = _get_units(np.imag(values / (2 * np.pi)))
+    prefix_scaling_x, prefix_x = _get_units(np.real(scaled_values))
+    prefix_scaling_y, prefix_y = _get_units(np.imag(scaled_values))
     return [
         _PlotData(
             xdata=xdata,
-            values=np.real(values / (2 * np.pi) / value_scaling_x),
-            ylabel="{0}$/2\\pi$\nI\n({1}Hz)".format(name, value_prefix_x),
+            values=np.real(scaled_values) / prefix_scaling_x,
+            ylabel=f"{scaled_name}\nI\n({prefix_x}{unit_symbol})",
         ),
         _PlotData(
             xdata=xdata,
-            values=np.imag(values / (2 * np.pi) / value_scaling_y),
-            ylabel="{0}$/2\\pi$\nQ\n({1}Hz)".format(name, value_prefix_y),
+            values=np.imag(scaled_values) / prefix_scaling_y,
+            ylabel=f"{scaled_name}\nQ\n({prefix_y}{unit_symbol})",
         ),
     ]
 
